@@ -31,7 +31,6 @@ Parallel_Make () {
 
 Home=`pwd`
 ZenLib_Options=""
-MacOptions="--with-macosx-version-min=10.5"
 
 OS=$(uname -s)
 # expr isn’t available on mac
@@ -53,11 +52,8 @@ if test -e ZenLib/Project/GNU/Library/configure; then
     cd ZenLib/Project/GNU/Library/
     test -e Makefile && rm Makefile
     chmod +x configure
-    if [ "$OS" = "mac" ]; then
-        ./configure $MacOptions $ZenLib_Options $*
-    else
-        ./configure $ZenLib_Options $*
-    fi
+   ./configure --enable-static --disable-shared $ZenLib_Options $*
+
     if test -e Makefile; then
         make clean
         Parallel_Make
@@ -84,11 +80,8 @@ if test -e MediaInfoLib/Project/GNU/Library/configure; then
     cd MediaInfoLib/Project/GNU/Library/
     test -e Makefile && rm Makefile
     chmod +x configure
-    if [ "$OS" = "mac" ]; then
-        ./configure $MacOptions $*
-    else
-        ./configure $*
-    fi
+   ./configure --enable-static --disable-shared $*
+
     if test -e Makefile; then
         make clean
         Parallel_Make
@@ -118,12 +111,6 @@ if test -e MediaInfo/Project/GNU/CLI/configure; then
     chmod +x configure
     ./configure --enable-staticlibs $*
 
-    if [ "$OS" = "mac" ]; then
-        ./configure $MacOptions --enable-staticlibs $*
-    else
-        ./configure --enable-staticlibs $*
-    fi
-
     if test -e Makefile; then
         make clean
         Parallel_Make
@@ -148,4 +135,4 @@ cd $Home
 echo "MediaInfo executable is MediaInfo/Project/GNU/CLI/mediainfo"
 echo "For installing, cd MediaInfo/Project/GNU/CLI && make install"
 
-unset -v Home ZenLib_Options MacOptions OS
+unset -v Home ZenLib_Options OS
