@@ -65,6 +65,11 @@ Preferences::Preferences()
     //Donate
     Donated=false;
     Donate_Display=true;
+
+    //Sponsor
+    Sponsored=false;
+    SponsorMessage=__T("");
+    SponsorUrl=__T("");
 }
 
 //***************************************************************************
@@ -193,6 +198,19 @@ int Preferences::Config_Load()
     if ((int64u)time(NULL)-Config(__T("Install")).To_int64u()<7*24*60*60)
         Donate_Display=false;
 
+    // Sponsor
+    if (Config(__T("Sponsored"))==__T("1"))
+    {
+        Sponsored=true;
+
+        Ztring Saved=Config(__T("SponsorMessage"));
+        Saved.FindAndReplace(__T("\\r\\n"), __T("\r\n"));
+        SponsorMessage.Write(Saved);
+
+        Saved=Config(__T("SponsorUrl"));
+        Saved.FindAndReplace(__T("\\r\\n"), __T("\r\n"));
+        SponsorUrl.Write(Saved);
+    }
 
     delete Reg_User; Reg_User=NULL;
 
@@ -220,6 +238,7 @@ int Preferences::Config_Save()
     if (Config(__T("FirstInstall")).empty()) Config(__T("FirstInstall")).From_Number((int64u)time(NULL));
     if (Config(__T("Donated")).empty()) Config(__T("Donated"))=__T("0");
     if (Config(__T("Donate_Display")).empty()) Config(__T("Donate_Display"))=__T("1");
+    if (Config(__T("Sponsored")).empty()) Config(__T("Sponsored"))=__T("0");
 
     HANDLE Temp=CreateFile((BaseFolder+__T("MediaInfo.cfg")).c_str(), GENERIC_WRITE, 0, NULL, CREATE_ALWAYS, 0, NULL);
     if (Temp==INVALID_HANDLE_VALUE)
@@ -450,6 +469,32 @@ void __fastcall ThreadInternetCheck::Execute()
         Prefs->Config_Save();
     }
 
+    //Sponsored
+    Prefs->Config(__T("Sponsored"))=__T("0");
+    Prefs->Config(__T("SponsorMessage"))=__T("");
+    Prefs->Config(__T("SponsorUrl"))=__T("");
+
+    ZtringListList Sponsor=Download.SubSheet(__T("ShowSponsor"));
+    if (int En=Sponsor.Find(__T("en"), 1)!=-1 && Sponsor[En](2)!=__T("") && Sponsor[En](3)!=__T(""))
+    {
+        Prefs->Config(__T("Sponsored"))=__T("1");
+        Ztring Message;
+        Ztring Url;
+        for (size_t Pos=0; Pos<Sponsor.size(); Pos++)
+        {
+            if (Sponsor[Pos](1)!=__T(""))
+            {
+                if (Sponsor[Pos](2)!=__T(""))
+                    Message+=(Message.empty()?__T(""):__T("\\r\\n"))+Sponsor[Pos](1)+__T(";")+Sponsor[Pos](2);
+                if (Sponsor[Pos](3)!=__T(""))
+                    Url+=(Url.empty()?__T(""):__T("\\r\\n"))+Sponsor[Pos](1)+__T(";")+Sponsor[Pos](3);
+            }
+        }
+        Prefs->Config(__T("SponsorMessage"))=Message.Quote();
+        Prefs->Config(__T("SponsorUrl"))=Url.Quote();
+    }
+    Prefs->Config_Save();
+
     //Chargement de pages
     ZtringListList Pages=Download.SubSheet(__T("Url"));
     for (size_t Pos=0; Pos<Pages.size(); Pos++)
@@ -1369,6 +1414,27 @@ int Preferences::ShellToolTip()
 //---------------------------------------------------------------------------
 ZenLib::Ztring &Preferences::Translate(ZenLib::Ztring Name)
 {
+    if (Name==__T("SponsorMessage") || Name==__T("SponsorUrl"))
+    {
+        Ztring Language=Translate(__T("  Language_ISO639"));
+        if (Name==__T("SponsorMessage"))
+        {
+            int Index=SponsorMessage.Find(Language, 0);
+            if (Index==-1 || SponsorMessage(Index)(1)==__T(""))
+                Index=SponsorMessage.Find(__T("en"), 0);
+
+            return SponsorMessage(Index)(1);
+        }
+        else if (Name==__T("SponsorUrl"))
+        {
+            int Index=SponsorUrl.Find(Language, 0);
+            if (Index==-1 || SponsorUrl(Index)(1)==__T(""))
+                Index=SponsorUrl.Find(__T("en"), 0);
+
+            return SponsorUrl(Index)(1);
+        }
+    }
+
     size_t Pos=Details[Prefs_Language].Find(Name, 0, 0, __T("=="), Ztring_CaseSensitive);
 
     //If not in the language, search for English language
