@@ -32,7 +32,7 @@
 //---------------------------------------------------------------------------
 
 //---------------------------------------------------------------------------
-#define MediaInfo_Version_GUI __T("19.09")
+#define MediaInfo_Version_GUI __T("20.09")
 //---------------------------------------------------------------------------
 
 //---------------------------------------------------------------------------
@@ -59,6 +59,8 @@ public:
     ZenLib::ZtringListListF Config;     //Configuration file
     ZenLib::ZtringList      FilesList[Prefs_Max];  //List of available files for an Item
     ZenLib::ZtringListListF Details[Prefs_Max];
+    ZenLib::ZtringListList  SponsorMessage;
+    ZenLib::ZtringListList  SponsorUrl;
 
     //Useful functions about preferences
     int Config_Create       ();
@@ -87,6 +89,9 @@ public:
     bool Donated;
     bool Donate_Display;
     bool NewVersion_Display;
+
+    //Sponsor
+    bool Sponsored;
 };
 
 //General preference for the whole program
