@@ -12,7 +12,7 @@
 #import "TreeView.h"
 #import "CompareView.h"
 
-typedef enum { Kind_Text, Kind_XML, Kind_JSON, Kind_PBCore, Kind_PBCore2, Kind_reVTMD, Kind_MPEG7, Kind_EBUCore_1_5, Kind_EBUCore_1_6, Kind_EBUCore_1_8_ps, Kind_EBUCore_1_8_sp, Kind_EBUCore_1_8_ps_json, Kind_EBUCore_1_8_sp_json, Kind_FIMS_1_1, Kind_FIMS_1_2, Kind_FIMS_1_3, Kind_NISO_Z39_87} ViewMenu_Kind;
+typedef enum { Kind_Text, Kind_HTML, Kind_XML, Kind_CSV, Kind_JSON, Kind_PBCore, Kind_PBCore2, Kind_reVTMD, Kind_MPEG7, Kind_EBUCore_1_5, Kind_EBUCore_1_6, Kind_EBUCore_1_8_ps, Kind_EBUCore_1_8_sp, Kind_EBUCore_1_8_ps_json, Kind_EBUCore_1_8_sp_json, Kind_FIMS_1_1, Kind_FIMS_1_2, Kind_FIMS_1_3, Kind_NISO_Z39_87} ViewMenu_Kind;
 
 @interface MyWindowController : NSWindowController {
 
@@ -32,7 +32,9 @@ typedef enum { Kind_Text, Kind_XML, Kind_JSON, Kind_PBCore, Kind_PBCore2, Kind_r
     IBOutlet NSArrayController *easyStreamsController;
     IBOutlet NSTableView *easyTable;
     IBOutlet CompareView *compareView;
-
+    IBOutlet NSSegmentedControl *subscribeButton;
+    IBOutlet NSToolbarItem *subscribeButtonItem;
+    IBOutlet NSToolbar *mainToolbar;
     oMediaInfoList *mediaList;
     NSInteger selectedFileIndex;
 
@@ -84,9 +86,10 @@ typedef enum { Kind_Text, Kind_XML, Kind_JSON, Kind_PBCore, Kind_PBCore2, Kind_r
 -(void)updateTextTabWithFileAtIndex:(NSUInteger)index;
 -(void)_updateTextTabWithContentOfAttributedTextAtIndex:(NSUInteger)index;
 -(void)_updateTextTabWithContentOfSimpleTextAtIndex:(NSUInteger)index;
-
+-(void)closeFileAtIndex:(NSUInteger)index;
 -(IBAction)selectNextTab:(id)sender;
 -(IBAction)selectPreviousTab:(id)sender;
 -(IBAction)closeFile:(id)sender;
 -(IBAction)closeAllFiles:(id)sender;
+-(IBAction)advancedMode:(id)sender;
 @end
