@@ -3,7 +3,7 @@
 //  MediaInfo
 //
 //  Created by Max Pozdeev on 07.02.12.
-//  Copyright 2012-2019 Jerome Martinez. All rights reserved.
+//  Copyright 2012-2020 Jerome Martinez. All rights reserved.
 //
 
 #import "MyWindowController.h"
@@ -11,6 +11,7 @@
 #import "MediaInfoExporter.h"
 #import "SubscriptionManager.h"
 #import "SubscribeWindowController.h"
+#import "ProgressDialog.h"
 #define kEasyTabIndex 0
 #define kTreeTabIndex 1
 #define kTextTabIndex 2
@@ -20,13 +21,17 @@
 #define kSubscribeMenuItemTag 11
 #define kViewMenuTag 50
 #define kCompareMenuItemTag 51
+#define kAdvancedMenuItemTag 52
+#define kAdvancedMenuItemSeparatorTag 53
 
 NSString* TextKindToNSString(ViewMenu_Kind kind)
 {
 	NSString *_ret = nil;
 	switch (kind)
 	{
+		case Kind_HTML:			_ret = @"HTML"; break;
 		case Kind_XML:			_ret = @"XML"; break;
+		case Kind_CSV:			_ret = @"CSV"; break;
 		case Kind_JSON:			_ret = @"JSON"; break;
 		case Kind_MPEG7:		_ret = @"MPEG-7"; break;
 		case Kind_PBCore:		_ret = @"PBCore"; break;
@@ -73,9 +78,53 @@ NSString* TextKindToNSString(ViewMenu_Kind kind)
     observers = [[NSMutableArray alloc] init];
 
     if (@available(macOS 10.9, *)) {
+        [subscribeButton setEnabled:YES forSegment:0];
         if([[SubscriptionManager shared] subscriptionActive]) {
             [self enableSubscription];
-        }
+
+             NSString* defaultView = [[NSUserDefaults standardUserDefaults] stringForKey:@"defaultView"];
+
+            if (defaultView == nil || [defaultView isEqualToString:@"Easy"])
+                [self selectEasyTab:nil];
+            else if ([defaultView isEqualToString:@"Tree"])
+                [self selectTreeTab:nil];
+            else if ([defaultView isEqualToString:@"Compare"])
+                [self selectCompareTab:nil];
+            else if ([defaultView isEqualToString:@"Text"])
+                [self selectTextTab:nil];
+            else if ([defaultView isEqualToString:@"XML"])
+                [self selectViewXML:nil];
+            else if ([defaultView isEqualToString:@"JSON"])
+                [self selectViewJSON:nil];
+            else if ([defaultView isEqualToString:@"MPEG-7"])
+                [self selectViewMPEG7:nil];
+            else if ([defaultView isEqualToString:@"PBCore"])
+                [self selectViewPBCore:nil];
+            else if ([defaultView isEqualToString:@"PBCore2"])
+                [self selectViewPBCore2:nil];
+            else if ([defaultView isEqualToString:@"EBUCore_1.5"])
+                [self selectViewEBUCore15:nil];
+             else if ([defaultView isEqualToString:@"EBUCore_1.6"])
+                [self selectViewEBUCore16:nil];
+            else if ([defaultView isEqualToString:@"EBUCore_1.8_ps"])
+                [self selectViewEBUCore18_ps:nil];
+            else if ([defaultView isEqualToString:@"EBUCore_1.8_sp"])
+                [self selectViewEBUCore18_sp:nil];
+            else if ([defaultView isEqualToString:@"EBUCore_1.8_ps_JSON"])
+                [self selectViewEBUCore18_ps_json:nil];
+            else if ([defaultView isEqualToString:@"EBUCore_1.8_sp_JSON"])
+                [self selectViewEBUCore18_sp_json:nil];
+            else if ([defaultView isEqualToString:@"FIMS_1.1"])
+                [self selectViewFIMS11:nil];
+            else if ([defaultView isEqualToString:@"FIMS_1.2"])
+                [self selectViewFIMS12:nil];
+            else if ([defaultView isEqualToString:@"FIMS_1.3"])
+                [self selectViewFIMS13:nil];
+            else if ([defaultView isEqualToString:@"reVTMD"])
+                [self selectViewReVTMD:nil];
+            else if ([defaultView isEqualToString:@"NISO_Z39.87"])
+                [self selectViewNISO_Z39_87:nil];
+            }
         else {
             [observers addObject:[[NSNotificationCenter defaultCenter] addObserverForName:[SubscriptionManager subscriptionStateChangedNotification] object:[SubscriptionManager shared] queue:[NSOperationQueue mainQueue] usingBlock:^(NSNotification *notification) {
                 [self enableSubscription];
@@ -103,11 +152,10 @@ NSString* TextKindToNSString(ViewMenu_Kind kind)
 #pragma mark GUI routines
 
 - (IBAction)openFile:(id)sender {
-	
 	NSOpenPanel *openPanel	= [NSOpenPanel openPanel];
 	[openPanel setCanChooseDirectories:YES];
 	[openPanel setAllowsMultipleSelection:YES];
-	
+	[openPanel setCanDownloadUbiquitousContents:NO];
 	[openPanel beginSheetModalForWindow:[self window] completionHandler:^(NSInteger result){
 		if(result == NSFileHandlingPanelOKButton) {
 			[self processFiles:[openPanel URLs]];
@@ -163,18 +211,11 @@ NSString* TextKindToNSString(ViewMenu_Kind kind)
 }
 
 -(IBAction)selectCompareTab:(id)sender {
-    if (!@available(macOS 10.9, *))
-        return;
-
-    if([SubscriptionManager shared].subscriptionActive) {
+    if (@available(macOS 10.9, *)) {
         [self hideFileSelector];
         [tabSelector setSelectedSegment:kCompareTabIndex];
         [tabs selectTabViewItemAtIndex:kCompareTabIndex];
     }
-    else {
-        [tabSelector setSelectedSegment:0];
-        [[SubscribeWindowController controller] show];
-    }
 }
 
 -(IBAction)selectEasyTab:(id)sender {
@@ -329,9 +370,13 @@ NSString* TextKindToNSString(ViewMenu_Kind kind)
 
 	NSInteger tag = exportFormatButton.selectedTag;
 
-	if (tag == 8 || tag == 9)
+	if (tag == 4 || tag == 12 || tag == 13)
 		[_exportSavePanel setAllowedFileTypes:@[@"json"]];
-	else if (tag > 0)
+	else if (tag == 3)
+		[_exportSavePanel setAllowedFileTypes:@[@"csv"]];
+	else if (tag == 1)
+		[_exportSavePanel setAllowedFileTypes:@[@"html"]];
+	else if (tag > 1)
 		[_exportSavePanel setAllowedFileTypes:@[@"xml"]];
 	else
 		[_exportSavePanel setAllowedFileTypes:@[@"txt"]];
@@ -363,51 +408,57 @@ NSString* TextKindToNSString(ViewMenu_Kind kind)
 			switch (exportFormatButton.selectedTag)
 			{
 				case 1:
-					format = TextKindToNSString(Kind_XML);
+					format = TextKindToNSString(Kind_HTML);
 					break;
 				case 2:
-					format = TextKindToNSString(Kind_JSON);
+					format = TextKindToNSString(Kind_XML);
 					break;
 				case 3:
-					format = TextKindToNSString(Kind_MPEG7);
+					format = TextKindToNSString(Kind_CSV);
 					break;
 				case 4:
-					format = TextKindToNSString(Kind_PBCore);
+					format = TextKindToNSString(Kind_JSON);
 					break;
 				case 5:
-					format = TextKindToNSString(Kind_PBCore2);
+					format = TextKindToNSString(Kind_MPEG7);
 					break;
 				case 6:
-					format = TextKindToNSString(Kind_EBUCore_1_5);
+					format = TextKindToNSString(Kind_PBCore);
 					break;
 				case 7:
-					format = TextKindToNSString(Kind_EBUCore_1_6);
+					format = TextKindToNSString(Kind_PBCore2);
 					break;
 				case 8:
-					format = TextKindToNSString(Kind_EBUCore_1_8_ps);
+					format = TextKindToNSString(Kind_EBUCore_1_5);
 					break;
 				case 9:
-					format = TextKindToNSString(Kind_EBUCore_1_8_sp);
+					format = TextKindToNSString(Kind_EBUCore_1_6);
 					break;
 				case 10:
-					format = TextKindToNSString(Kind_EBUCore_1_8_ps_json);
+					format = TextKindToNSString(Kind_EBUCore_1_8_ps);
 					break;
 				case 11:
-					format = TextKindToNSString(Kind_EBUCore_1_8_sp_json);
+					format = TextKindToNSString(Kind_EBUCore_1_8_sp);
 					break;
 				case 12:
-					format = TextKindToNSString(Kind_FIMS_1_1);
+					format = TextKindToNSString(Kind_EBUCore_1_8_ps_json);
 					break;
 				case 13:
-					format = TextKindToNSString(Kind_FIMS_1_2);
+					format = TextKindToNSString(Kind_EBUCore_1_8_sp_json);
 					break;
 				case 14:
-					format = TextKindToNSString(Kind_FIMS_1_3);
+					format = TextKindToNSString(Kind_FIMS_1_1);
 					break;
 				case 15:
-					format = TextKindToNSString(Kind_reVTMD);
+					format = TextKindToNSString(Kind_FIMS_1_2);
 					break;
 				case 16:
+					format = TextKindToNSString(Kind_FIMS_1_3);
+					break;
+				case 17:
+					format = TextKindToNSString(Kind_reVTMD);
+					break;
+				case 18:
 					format = TextKindToNSString(Kind_NISO_Z39_87);
 					break;
 				case 0:
@@ -446,17 +497,34 @@ NSString* TextKindToNSString(ViewMenu_Kind kind)
         if(main && main.submenu) {
             NSMenuItem *item = [main.submenu itemWithTag:kSubscribeMenuItemTag];
             if(item) {
-                [item setTitle:@"Manage Subscription"];
+                [item setTitle:NSLocalizedString(@"Manage Subscription", @"Manage Subscription")];
             }
         }
 
         NSMenuItem *view = [menu itemWithTag:kViewMenuTag];
         if(view && view.submenu) {
-            NSMenuItem *item = [view.submenu itemWithTag:kCompareMenuItemTag];
-            [item setHidden:NO];
+            NSMenuItem *compare = [view.submenu itemWithTag:kCompareMenuItemTag];
+            [compare setHidden:NO];
+
+            NSMenuItem *advanced = [view.submenu itemWithTag:kAdvancedMenuItemTag];
+            [advanced setHidden:NO];
+
+            NSMenuItem *separator = [view.submenu itemWithTag:kAdvancedMenuItemSeparatorTag];
+            [separator setHidden:NO];
         }
     }
 
+    if (@available(macOS 10.13, *)) {
+        [tabSelector setToolTip:NSLocalizedString(@"Compare View", @"Compare View") forSegment:kCompareTabIndex];
+        [subscribeButton setToolTip:NSLocalizedString(@"Manage subscription", @"Manage Subscription") forSegment:0];
+    }
+
+    NSInteger index = [[mainToolbar items] indexOfObject:subscribeButtonItem];
+    if (index != NSNotFound)
+        [mainToolbar removeItemAtIndex:index];
+
+    [tabSelector setEnabled:YES forSegment:kCompareTabIndex];
+
     /* NSUInteger lastSegment = tabSelector.segmentCount - 1;
     NSString *segmentLabel = [tabSelector labelForSegment:lastSegment];
     NSImage *segmentImage = [tabSelector imageForSegment:lastSegment];
@@ -502,23 +570,38 @@ NSString* TextKindToNSString(ViewMenu_Kind kind)
 -(void)processFiles:(NSArray *)URLs {
 	
 	//Process files...
-    if(!mediaList)
-	    mediaList = [[oMediaInfoList alloc] init]; //dont care about release
+	if(!mediaList)
+		mediaList = [[oMediaInfoList alloc] init]; //dont care about release
 
-    NSInteger oldIndex = [mediaList count]-1;
+	NSInteger oldCount = [mediaList count];
 
-	if([mediaList openFiles:URLs]) {
-		
+	if([URLs count]==1 && [[NSFileManager defaultManager] fileExistsAtPath:[URLs[0] path]]) {
+		if(![mediaList openFiles:URLs]) {
+			//Report about some error while opening?
+			[[NSAlert alertWithMessageText:NSLocalizedString(@"Error", @"Error header")
+				defaultButton:nil
+				alternateButton:nil
+				otherButton:nil
+				informativeTextWithFormat:NSLocalizedString(@"Can not open file(s)", @"Error text while open")] runModal];
+		}
+	}
+	else {
+		ProgressDialog *wc = [[ProgressDialog alloc] initWithWindowNibName:@"ProgressDialog"];
+		[wc setItems:URLs];
+		[wc setMediaList:mediaList];
+
+		[NSApp runModalForWindow:wc.window];
+		[wc.window close];
+		wc = nil;
+	}
+
+	if([mediaList count]>oldCount) {
 		//Update GUI
-		
 		NSArray *files = [mediaList files];
-		
 		NSUInteger max = [files count];
-		
 		NSMutableArray *array = [NSMutableArray array];
-		
+
 		for(NSUInteger i=0; i<max; i++) {
-			
 			NSDictionary *listElement = [NSDictionary dictionaryWithObjectsAndKeys:
 										 [files objectAtIndex:i], @"value",
 										 [files objectAtIndex:i], @"title",
@@ -526,45 +609,30 @@ NSString* TextKindToNSString(ViewMenu_Kind kind)
 			
 			[array addObject:listElement];
 		}
-		
+
 		[comboController setContent:array];
 		[compareView setFiles:mediaList];
 		[treeView setFiles:mediaList];
 
 		//display first added file
-               [self setSelectedFileIndex:oldIndex+1];
-               [comboController setSelectionIndex:oldIndex+1];
+		[self setSelectedFileIndex:oldCount];
+		[comboController setSelectionIndex:oldCount];
 	}
-	else {
-		//Report about some error while opening?
-		
-		[[NSAlert alertWithMessageText:NSLocalizedString(@"Error", @"Error header")
-						 defaultButton:nil 
-					   alternateButton:nil 
-						   otherButton:nil 
-			 informativeTextWithFormat:NSLocalizedString(@"Can not open file(s)", @"Error text while open")] runModal];
-	}
-	
-	
 }
 
 
 -(void)showFileAtIndex:(NSUInteger)index {
-	
 	// Easy view
-	
 	[self updateEasyTabWithFileAtIndex:index];
-	
-	
-	//Text View
 
+	//Text View
 	[self updateTextTabWithFileAtIndex:index];
 
 	//tree view
-       [treeView setIndex:index];
+	[treeView setIndex:index];
 
-    // compare view
-    [compareView reload];
+	// compare view
+	[compareView reload];
 
 	//recent items
 	NSString *filename = [mediaList filenameAtIndex:index];
@@ -903,13 +971,39 @@ NSString* TextKindToNSString(ViewMenu_Kind kind)
         return mediaList && [tabs indexOfTabViewItem:tabs.selectedTabViewItem] != kCompareTabIndex && [mediaList count] && selectedFileIndex > 0;
     }
     else if(action == @selector(closeFile:) || action == @selector(closeAllFiles:)) {
-        return mediaList && [mediaList count];
+        if(action == @selector(closeFile:) && [tabs indexOfTabViewItem:tabs.selectedTabViewItem] == kCompareTabIndex)
+            return mediaList && compareView.selectedIndex > 0 && compareView.selectedIndex - 1 < [mediaList count];
 
+        return mediaList && [mediaList count];
     }
 
 	return YES;
 }
 
+-(void)closeFileAtIndex:(NSUInteger)index {
+    if(mediaList && index < [mediaList count]) {
+        NSUInteger oldSelectedFileIndex = selectedFileIndex;
+        NSUInteger oldComboControllerIndex = [comboController selectionIndex];
+
+        NSUInteger newSelectedFileIndex = oldSelectedFileIndex;
+        NSUInteger newComboControllerIndex = oldComboControllerIndex;
+
+        if((selectedFileIndex > 0) && ((index < selectedFileIndex) || (index == selectedFileIndex && index == [mediaList count] - 1))) {
+            newSelectedFileIndex = oldSelectedFileIndex - 1;
+            newComboControllerIndex = oldComboControllerIndex - 1;
+        }
+
+        NSMutableArray* array = [comboController content];
+        [array removeObjectAtIndex:index];
+        [comboController setContent:array];
+
+        [mediaList closeAtIndex:index];
+
+        [comboController setSelectionIndex:newComboControllerIndex];
+        [self setSelectedFileIndex:newSelectedFileIndex];
+    }
+}
+
 -(IBAction)selectNextTab:(id)sender {
     if(mediaList && [tabs indexOfTabViewItem:tabs.selectedTabViewItem] != kCompareTabIndex && [mediaList count] && selectedFileIndex < [mediaList count] - 1) {
         [comboController selectNext:nil];
@@ -926,6 +1020,14 @@ NSString* TextKindToNSString(ViewMenu_Kind kind)
 
 -(IBAction)closeFile:(id)sender {
     if(mediaList && [mediaList count]) {
+
+        if ([tabs indexOfTabViewItem:tabs.selectedTabViewItem] == kCompareTabIndex) {
+            if(compareView.selectedIndex > 0 && (compareView.selectedIndex - 1) < [mediaList count])
+                [self closeFileAtIndex:(compareView.selectedIndex - 1)];
+
+            return;
+        }
+
         NSUInteger oldSelectedFileIndex = selectedFileIndex;
         NSUInteger oldComboControllerIndex = [comboController selectionIndex];
         NSUInteger newSelectedFileIndex = oldSelectedFileIndex;
@@ -956,4 +1058,23 @@ NSString* TextKindToNSString(ViewMenu_Kind kind)
         [self setSelectedFileIndex:0];
     }
 }
+
+- (IBAction)clickOnSubscribe:(id)sender {
+    [[SubscribeWindowController controller] show];
+}
+
+-(IBAction)advancedMode:(id)sender {
+    if([sender isKindOfClass: [NSMenuItem class]]) {
+        NSMenuItem* item = sender;
+
+        BOOL newState = !item.state;
+        [item setState:newState];
+
+        [oMediaInfoList setOptionStatic:@"Complete" withValue:(newState?@"1":@"")];
+
+        if(mediaList && selectedFileIndex < [mediaList count]) {
+            [self showFileAtIndex:selectedFileIndex];
+        }
+    }
+}
 @end
