@@ -7,9 +7,9 @@
 #ifndef EXPORT_H
 #define EXPORT_H
 
-#include <QtGui/QDialog>
-#include <QtCore/QIODevice>
-#include <QtCore/QDebug>
+#include <QDialog>
+#include <QIODevice>
+#include <QDebug>
 
 namespace Ui {
     class Export;
@@ -22,10 +22,20 @@ public:
         TEXT=0,
         HTML=1,
         XML,
+        JSON,
         PBCORE,
+        PBCORE2,
+        EBUCORE_1_5,
+        EBUCORE_1_6,
+        EBUCORE_1_8_ps,
+        EBUCORE_1_8_sp,
+        EBUCORE_1_8_ps_JSON,
+        EBUCORE_1_8_sp_JSON,
+        FIMS_1_1,
+        FIMS_1_2,
+        FIMS_1_3,
         MPEG7,
-        CSV,
-
+        NISO_Z39_87,
         NB_EXPORT_MODE
     };
 
@@ -37,6 +47,7 @@ public:
     QIODevice::OpenMode getOpenMode();
     bool isAdvancedChecked();
     QString extension(int mode);
+    QString extensionName(int mode);
     QString name(int mode);
 
 protected:
@@ -44,11 +55,12 @@ protected:
 
 private:
     Ui::Export *ui;
+    QString path;
 
 private slots:
     void on_checkBoxAdvanced_toggled(bool checked);
     void on_comboBoxMode_currentIndexChanged(int index);
-    void on_toolButton_pressed();
+    void on_buttonBox_accepted();
 };
 
 #endif // EXPORT_H
