@@ -176,7 +176,7 @@ void __fastcall TMainF::GUI_Configure()
     if (Screen->Width>=1024)
         Width=700;
     if (Screen->Width>=1280)
-        Width=820;
+        Width=830;
     if (Screen->Height>=768)
         Height=500;
     if (Screen->Height>=1024)
@@ -593,10 +593,12 @@ void __fastcall TMainF::Translate()
         }
         */
     }
-    //if (Prefs->Donated) //No more
+
+    M_Sponsor->Visible=false;
+    if (Prefs->Sponsored && !Prefs->Donated && !Prefs->Translate(__T("SponsorMessage")).empty() && !Prefs->Translate(__T("SponsorMessage")).empty())
     {
-        M_Tektronix->Visible=false;
-        Tool_Tektronix->Visible=false;
+        M_Sponsor->Caption =  + Prefs->Translate(__T("SponsorMessage")).c_str();
+        M_Sponsor->Visible=true;
     }
 }
 
@@ -696,6 +698,7 @@ void __fastcall TMainF::Refresh(TTabSheet *Page)
         Page_Tree_Tree->Items->Clear();
         TTreeNode* Top=NULL;
 
+        I->Option(__T("File_ExpandSubs"), __T("1"));
         for (size_t FilePos=0; FilePos<FilesCount; FilePos++)
         {
             //Pour chaque fichier
@@ -719,6 +722,10 @@ void __fastcall TMainF::Refresh(TTabSheet *Page)
                         A+=B;
                     }
                     TTreeNode* Node=Page_Tree_Tree->Items->AddChild(Parent, A.c_str());
+
+                    std::vector<TTreeNode*> Tree;
+                    Tree.push_back(Node);
+
                     unsigned ChampsCount=I->Count_Get(FilePos, (stream_t)StreamKind, StreamPos);
                     for (size_t Champ_Pos=0; Champ_Pos<ChampsCount; Champ_Pos++)
                     {
@@ -734,13 +741,29 @@ void __fastcall TMainF::Refresh(TTabSheet *Page)
                             if (D.empty())
                                 D=I->Get(FilePos, (stream_t)StreamKind, StreamPos, Champ_Pos, Info_Name); //Texte n'existe pas
                             //Affichage
-                            Page_Tree_Tree->Items->AddChild(Node, (D + __T(": ") + A.c_str()).c_str());
+                            size_t Level=D.find_first_not_of(__T(' '));
+
+                            bool Hide=false;
+                            if (A==__T("Yes") && Champ_Pos+1<ChampsCount)
+                                Hide=I->Get(FilePos, (stream_t)StreamKind, StreamPos, Champ_Pos+1, Info_Name_Text).find_first_not_of(__T(' '))>Level;
+
+                            if (Level && Level!=(size_t)-1)
+                                D=D.substr(Level);
+
+                            if(Level==Tree.size() && Tree.back()->GetLastChild())
+                                Tree.push_back(Tree.back()->GetLastChild());
+                            else if(Level<Tree.size()-1)
+                                Tree.resize(Level+1);
+
+                            Page_Tree_Tree->Items->AddChild(Tree.back(), Hide?D.c_str():(D + __T(": ") + A).c_str());
                         }
                     }
+                    Node->Expand(false);
                 }
             }
+            Parent->Expand(false);
         }
-        Page_Tree_Tree->FullExpand();
+        I->Option(__T("File_ExpandSubs"), __T("0"));
         if (Top)
             Top->MakeVisible();
         Page_Tree_Tree->Visible=true;
@@ -922,8 +945,6 @@ void __fastcall TMainF::Refresh(TTabSheet *Page)
         //0 fichier
     {
         Caption=MEDIAINFO_TITLE;
-        if (Prefs->Donated)
-            Caption+=" - Sponsored by Tektronix";
     }
     else if (FilesCount==1)
         //un fichier
@@ -1779,9 +1800,8 @@ void __fastcall TMainF::M_NewVersionClick(TObject *Sender)
     ShellExecute(NULL, NULL, (Ztring(__T("http://mediaarea.net/"))+Prefs->Translate(__T("  Language_ISO639"))+__T("/MediaInfo/?NewVersionRequested=true")).c_str(), NULL, NULL, SW_SHOWNORMAL);
 }
 
-void __fastcall TMainF::M_TektronixClick(TObject *Sender)
-{
-    ShellExecute(NULL, NULL, __T("http://www.tek.com/file-based-qc-solutions"), NULL, NULL, SW_SHOWNORMAL);
-}
 //---------------------------------------------------------------------------
-
+void __fastcall TMainF::M_SponsorClick(TObject *Sender)
+{
+    ShellExecute(NULL, NULL, Prefs->Translate(__T("SponsorUrl")).c_str(), NULL, NULL, SW_SHOWNORMAL);
+}
