@@ -53,6 +53,7 @@ enum
     ID_Menu_View_FIMS_1_1,
     ID_Menu_View_FIMS_1_2,
     ID_Menu_View_reVTMD,
+    ID_Menu_View_NISO_Z39_87,
     ID_Menu_Debug_Complete,
     ID_Menu_Debug_Details,
     ID_Menu_Debug_Demux,
@@ -89,6 +90,7 @@ BEGIN_EVENT_TABLE(GUI_Main, wxFrame)
     EVT_MENU(ID_Menu_View_FIMS_1_1,         GUI_Main::OnMenu_View_FIMS_1_1)
     EVT_MENU(ID_Menu_View_FIMS_1_2,         GUI_Main::OnMenu_View_FIMS_1_2)
     EVT_MENU(ID_Menu_View_reVTMD,           GUI_Main::OnMenu_View_reVTMD)
+    EVT_MENU(ID_Menu_View_NISO_Z39_87,      GUI_Main::OnMenu_View_NISO_Z39_87)
     EVT_MENU(ID_Menu_Debug_Complete,        GUI_Main::OnMenu_Debug_Complete)
     EVT_MENU(ID_Menu_Debug_Details,         GUI_Main::OnMenu_Debug_Details)
     EVT_MENU(ID_Menu_Debug_Demux_None,      GUI_Main::OnMenu_Debug_Demux_None)
@@ -148,6 +150,7 @@ void GUI_Main::Menu_Create()
     Menu_View_EBUCore_1_8_sp_json  =Menu_View->AppendRadioItem(ID_Menu_View_EBUCore_1_8_sp_json, __T("EBUCore 1.8 (acq. metadata: segment then parameter, json output)"));
     Menu_View_FIMS_1_1          =Menu_View->AppendRadioItem(ID_Menu_View_FIMS_1_1, __T("FIMS 1.1 (beta)"));
     Menu_View_FIMS_1_2          =Menu_View->AppendRadioItem(ID_Menu_View_FIMS_1_2, __T("FIMS 1.2 (beta)"));
+    Menu_View_NISO_Z39_87       =Menu_View->AppendRadioItem(ID_Menu_View_NISO_Z39_87, __T("NISO Z39.87"));
     Menu_View_reVTMD            =Menu_View->AppendRadioItem(ID_Menu_View_reVTMD, __T("reVTMD"));
 
     //Debug - Demux
@@ -440,6 +443,17 @@ void GUI_Main::OnMenu_View_reVTMD(wxCommandEvent& WXUNUSED(event))
     delete View; View = View_New;
 }
 
+//---------------------------------------------------------------------------
+void GUI_Main::OnMenu_View_NISO_Z39_87(wxCommandEvent& WXUNUSED(event))
+{
+    //Configuring
+    C->Menu_View_NISO_Z39_87();
+
+    //Showing
+    GUI_Main_Common_Core* View_New = new GUI_Main_Text(C, this);
+    delete View; View = View_New;
+}
+
 //---------------------------------------------------------------------------
 void GUI_Main::OnMenu_Debug_Complete(wxCommandEvent& WXUNUSED(event))
 {
